/*******************************************************************************
* File Name: Po.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_Po_H) /* Pins Po_H */
#define CY_PINS_Po_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "Po_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 Po__PORT == 15 && ((Po__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    Po_Write(uint8 value);
void    Po_SetDriveMode(uint8 mode);
uint8   Po_ReadDataReg(void);
uint8   Po_Read(void);
void    Po_SetInterruptMode(uint16 position, uint16 mode);
uint8   Po_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the Po_SetDriveMode() function.
     *  @{
     */
        #define Po_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define Po_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define Po_DM_RES_UP          PIN_DM_RES_UP
        #define Po_DM_RES_DWN         PIN_DM_RES_DWN
        #define Po_DM_OD_LO           PIN_DM_OD_LO
        #define Po_DM_OD_HI           PIN_DM_OD_HI
        #define Po_DM_STRONG          PIN_DM_STRONG
        #define Po_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define Po_MASK               Po__MASK
#define Po_SHIFT              Po__SHIFT
#define Po_WIDTH              1u

/* Interrupt constants */
#if defined(Po__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in Po_SetInterruptMode() function.
     *  @{
     */
        #define Po_INTR_NONE      (uint16)(0x0000u)
        #define Po_INTR_RISING    (uint16)(0x0001u)
        #define Po_INTR_FALLING   (uint16)(0x0002u)
        #define Po_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define Po_INTR_MASK      (0x01u) 
#endif /* (Po__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define Po_PS                     (* (reg8 *) Po__PS)
/* Data Register */
#define Po_DR                     (* (reg8 *) Po__DR)
/* Port Number */
#define Po_PRT_NUM                (* (reg8 *) Po__PRT) 
/* Connect to Analog Globals */                                                  
#define Po_AG                     (* (reg8 *) Po__AG)                       
/* Analog MUX bux enable */
#define Po_AMUX                   (* (reg8 *) Po__AMUX) 
/* Bidirectional Enable */                                                        
#define Po_BIE                    (* (reg8 *) Po__BIE)
/* Bit-mask for Aliased Register Access */
#define Po_BIT_MASK               (* (reg8 *) Po__BIT_MASK)
/* Bypass Enable */
#define Po_BYP                    (* (reg8 *) Po__BYP)
/* Port wide control signals */                                                   
#define Po_CTL                    (* (reg8 *) Po__CTL)
/* Drive Modes */
#define Po_DM0                    (* (reg8 *) Po__DM0) 
#define Po_DM1                    (* (reg8 *) Po__DM1)
#define Po_DM2                    (* (reg8 *) Po__DM2) 
/* Input Buffer Disable Override */
#define Po_INP_DIS                (* (reg8 *) Po__INP_DIS)
/* LCD Common or Segment Drive */
#define Po_LCD_COM_SEG            (* (reg8 *) Po__LCD_COM_SEG)
/* Enable Segment LCD */
#define Po_LCD_EN                 (* (reg8 *) Po__LCD_EN)
/* Slew Rate Control */
#define Po_SLW                    (* (reg8 *) Po__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define Po_PRTDSI__CAPS_SEL       (* (reg8 *) Po__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define Po_PRTDSI__DBL_SYNC_IN    (* (reg8 *) Po__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define Po_PRTDSI__OE_SEL0        (* (reg8 *) Po__PRTDSI__OE_SEL0) 
#define Po_PRTDSI__OE_SEL1        (* (reg8 *) Po__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define Po_PRTDSI__OUT_SEL0       (* (reg8 *) Po__PRTDSI__OUT_SEL0) 
#define Po_PRTDSI__OUT_SEL1       (* (reg8 *) Po__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define Po_PRTDSI__SYNC_OUT       (* (reg8 *) Po__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(Po__SIO_CFG)
    #define Po_SIO_HYST_EN        (* (reg8 *) Po__SIO_HYST_EN)
    #define Po_SIO_REG_HIFREQ     (* (reg8 *) Po__SIO_REG_HIFREQ)
    #define Po_SIO_CFG            (* (reg8 *) Po__SIO_CFG)
    #define Po_SIO_DIFF           (* (reg8 *) Po__SIO_DIFF)
#endif /* (Po__SIO_CFG) */

/* Interrupt Registers */
#if defined(Po__INTSTAT)
    #define Po_INTSTAT            (* (reg8 *) Po__INTSTAT)
    #define Po_SNAP               (* (reg8 *) Po__SNAP)
    
	#define Po_0_INTTYPE_REG 		(* (reg8 *) Po__0__INTTYPE)
#endif /* (Po__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_Po_H */


/* [] END OF FILE */
