/*******************************************************************************
* File Name: PotPin.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_PotPin_H) /* Pins PotPin_H */
#define CY_PINS_PotPin_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "PotPin_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 PotPin__PORT == 15 && ((PotPin__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    PotPin_Write(uint8 value);
void    PotPin_SetDriveMode(uint8 mode);
uint8   PotPin_ReadDataReg(void);
uint8   PotPin_Read(void);
void    PotPin_SetInterruptMode(uint16 position, uint16 mode);
uint8   PotPin_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the PotPin_SetDriveMode() function.
     *  @{
     */
        #define PotPin_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define PotPin_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define PotPin_DM_RES_UP          PIN_DM_RES_UP
        #define PotPin_DM_RES_DWN         PIN_DM_RES_DWN
        #define PotPin_DM_OD_LO           PIN_DM_OD_LO
        #define PotPin_DM_OD_HI           PIN_DM_OD_HI
        #define PotPin_DM_STRONG          PIN_DM_STRONG
        #define PotPin_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define PotPin_MASK               PotPin__MASK
#define PotPin_SHIFT              PotPin__SHIFT
#define PotPin_WIDTH              1u

/* Interrupt constants */
#if defined(PotPin__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in PotPin_SetInterruptMode() function.
     *  @{
     */
        #define PotPin_INTR_NONE      (uint16)(0x0000u)
        #define PotPin_INTR_RISING    (uint16)(0x0001u)
        #define PotPin_INTR_FALLING   (uint16)(0x0002u)
        #define PotPin_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define PotPin_INTR_MASK      (0x01u) 
#endif /* (PotPin__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define PotPin_PS                     (* (reg8 *) PotPin__PS)
/* Data Register */
#define PotPin_DR                     (* (reg8 *) PotPin__DR)
/* Port Number */
#define PotPin_PRT_NUM                (* (reg8 *) PotPin__PRT) 
/* Connect to Analog Globals */                                                  
#define PotPin_AG                     (* (reg8 *) PotPin__AG)                       
/* Analog MUX bux enable */
#define PotPin_AMUX                   (* (reg8 *) PotPin__AMUX) 
/* Bidirectional Enable */                                                        
#define PotPin_BIE                    (* (reg8 *) PotPin__BIE)
/* Bit-mask for Aliased Register Access */
#define PotPin_BIT_MASK               (* (reg8 *) PotPin__BIT_MASK)
/* Bypass Enable */
#define PotPin_BYP                    (* (reg8 *) PotPin__BYP)
/* Port wide control signals */                                                   
#define PotPin_CTL                    (* (reg8 *) PotPin__CTL)
/* Drive Modes */
#define PotPin_DM0                    (* (reg8 *) PotPin__DM0) 
#define PotPin_DM1                    (* (reg8 *) PotPin__DM1)
#define PotPin_DM2                    (* (reg8 *) PotPin__DM2) 
/* Input Buffer Disable Override */
#define PotPin_INP_DIS                (* (reg8 *) PotPin__INP_DIS)
/* LCD Common or Segment Drive */
#define PotPin_LCD_COM_SEG            (* (reg8 *) PotPin__LCD_COM_SEG)
/* Enable Segment LCD */
#define PotPin_LCD_EN                 (* (reg8 *) PotPin__LCD_EN)
/* Slew Rate Control */
#define PotPin_SLW                    (* (reg8 *) PotPin__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define PotPin_PRTDSI__CAPS_SEL       (* (reg8 *) PotPin__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define PotPin_PRTDSI__DBL_SYNC_IN    (* (reg8 *) PotPin__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define PotPin_PRTDSI__OE_SEL0        (* (reg8 *) PotPin__PRTDSI__OE_SEL0) 
#define PotPin_PRTDSI__OE_SEL1        (* (reg8 *) PotPin__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define PotPin_PRTDSI__OUT_SEL0       (* (reg8 *) PotPin__PRTDSI__OUT_SEL0) 
#define PotPin_PRTDSI__OUT_SEL1       (* (reg8 *) PotPin__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define PotPin_PRTDSI__SYNC_OUT       (* (reg8 *) PotPin__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(PotPin__SIO_CFG)
    #define PotPin_SIO_HYST_EN        (* (reg8 *) PotPin__SIO_HYST_EN)
    #define PotPin_SIO_REG_HIFREQ     (* (reg8 *) PotPin__SIO_REG_HIFREQ)
    #define PotPin_SIO_CFG            (* (reg8 *) PotPin__SIO_CFG)
    #define PotPin_SIO_DIFF           (* (reg8 *) PotPin__SIO_DIFF)
#endif /* (PotPin__SIO_CFG) */

/* Interrupt Registers */
#if defined(PotPin__INTSTAT)
    #define PotPin_INTSTAT            (* (reg8 *) PotPin__INTSTAT)
    #define PotPin_SNAP               (* (reg8 *) PotPin__SNAP)
    
	#define PotPin_0_INTTYPE_REG 		(* (reg8 *) PotPin__0__INTTYPE)
#endif /* (PotPin__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_PotPin_H */


/* [] END OF FILE */
