/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>
#include <stdio.h>

#define buffer 16
#define RD_BUFFER_LEN (12u)
#define WR_BUFFER_LEN (64u)
#define USBFS_DEVICE    (0u)
#define samples (15000u)
#define div (1u)                        // One sample is stored eacg div samples

void PrintToUSBUART(char8 * outText);   // Send Sring with USBFS (UART)
void DMA_Config(void);

uint sample = 0;
uint subsample = 0;
uint32 SADCVector[samples];
uint32 SADC;
float Voltage;
int working = 0;

char8 str[12];
uint16 count;
uint8 rdBuffer[RD_BUFFER_LEN];      //Reading Buffer
uint8 wrBuffer[WR_BUFFER_LEN];      //Writing Buffer
char rdChar;
uint16 bytes;                       // Bytes received
    
int listo=0;
uint i;

/* Defines for DMA */
#define DMA_BYTES_PER_BURST 2
#define DMA_REQUEST_PER_BURST 1
#define DMA_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_DST_BASE (CYDEV_PERIPH_BASE)

/* General constat defines */
#define FILTER_DATA_ALIGN       (0x05u)


CY_ISR(filterISR){                  // Interrupt when data is ready 
    LED_1_Write(1);
    working = 1;
    SADC = Filter_Read16(Filter_CHANNEL_A);
    if (sample % div == 0){
        //SADCVector[subsample] = ADC1_GetResult32();    // Store data and put flag down
        SADCVector[subsample] = SADC;
        subsample++;
    }
    else {
        
    }
    
    if (sample >= div*(samples - 1)){ // Data vector is done
        ADC1_Stop();
        Filter_Stop();
             
        LED_1_Write(0);
        working = 0;
    }
    sample++;
    
}

int main()
{
    
    CyGlobalIntEnable; /* Enable global interrupts. */
    
    USBUART_Start(0, USBUART_3V_OPERATION);
    while(!USBUART_GetConfiguration()){             // Wait configuration
    }
    USBUART_CDC_Init(); 
    
    isrFilt_StartEx(filterISR);

    LED_1_Write(0);
    LED_2_Write(0);

    for(;;)
    {                     
        
        while(USBUART_DataIsReady() == 0u){  // Wait data available
        }
        if (0u != USBUART_DataIsReady()){
            //USBUART_GetAll(rdBuffer);
                                
            rdChar = USBUART_GetChar();
            //bytes = USBUART_GetAll(rdBuffer);
            //rdChar = rdBuffer [0];
        }    
        switch (rdChar) {
            case '1':                   // Store data
            if (working == 0){
                sample = 0;             // Counter to 0
                subsample = 0;
                
                ADC1_Start();
                ADC1_StartConvert();
                //ADC1_IRQ_Enable();
                //ADC1_SetCoherency(ADC1_COHER_MID);    // 16 bits The full range results will be aligned to bit 15
                //ADC_IRQ_Start();
    
                Filter_Start();
                Filter_SetCoherency(Filter_CHANNEL_A, Filter_KEY_MID);
                Filter_SetDalign(Filter_STAGEA_DALIGN, Filter_ENABLED);
                //Filter_DALIGN_REG =  Filter_DALIGN_REG | FILTER_DATA_ALIGN;
                //Filter_COHER_REG=0x55;
                DMA_Config();
                
            }
                    
                break;
            case '2':                   // Send data
                if (sample >= div*(samples - 1)){
                    LED_2_Write(1);
                    for (i = 0; i <= (samples - 1); i++){
                        //Voltage = ADC1_CountsTo_Volts(SADCVector[i]);
                        Voltage = SADCVector[i] * 3.3 / 65536;
                        sprintf(str,"%.5f", Voltage);
                        PrintToUSBUART(str);                
                    }  
                    i=0;
                    sample = 0;     // Counter to 0
                    subsample = 0;
                    LED_2_Write(0);
                    
                }    
                break;
            default: 
                break;
            }
            working = 0;
                                  
    }
}

void PrintToUSBUART(char8 * outText)
{
    /* Wait till the CDC device is ready before sending data */
    while(USBUART_CDCIsReady() == 0u);
    /* Send strlen number of characters of wrBuffer to USBUART */
    USBUART_PutData((uint8 *)outText, strlen(outText));
    CyDelay(1u);
}
/*******************************************************************************
* Function Name: DMA_Config
********************************************************************************
*
* Summary:
*  Initializes and sets up DMA for use (generated by DMA Wizard)
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DMA_Config(void){
    uint8 DMA_Chan;
    uint8 DMA_TD[1];
    
    DMA_Chan = DMA_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, 
      HI16(DMA_SRC_BASE), HI16(DMA_DST_BASE));
    DMA_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(DMA_TD[0], 2, DMA_TD[0], 0);
    CyDmaTdSetAddress(DMA_TD[0], LO16((uint32)ADC1_DEC_SAMP_16B_PTR), LO16((uint32)Filter_STAGEA_PTR));
    CyDmaChSetInitialTd(DMA_Chan, DMA_TD[0]);
    CyDmaChEnable(DMA_Chan, 1);
}
/* [] END OF FILE */
